@@ -57,6 +57,12 @@ MATCH_TAIL     = 3
 MATCH_EXACT    = 4
 MATCH_LAST     = 5
 
+# GtkMenuDirectionType's
+MENU_DIR_PARENT = 0
+MENU_DIR_CHILD  = 1
+MENU_DIR_NEXT   = 2
+MENU_DIR_PREV   = 3
+
 # GtkMenuFactoryType's
 MENU_FACTORY_MENU        = 0
 MENU_FACTORY_MENU_BAR    = 1
@@ -133,6 +139,10 @@ SHADOW_OUT        = 2
 SHADOW_ETCHED_IN  = 3
 SHADOW_ETCHED_OUT = 4
 
+# GtkSortType's
+SORT_ASCENDING  = 0
+SORT_DESCENDING = 1
+
 # GtkStateType's
 STATE_NORMAL      = 0
 STATE_ACTIVE      = 1
@@ -198,7 +208,8 @@ CAN_DEFAULT      = 1 << 13
 HAS_DEFAULT      = 1 << 14
 HAS_GRAB         = 1 << 15
 RC_STYLE         = 1 << 16
-BASIC            = 1 << 17
+COMPOSITE_CHILD  = 1 << 17
+BASIC            = 1 << 18
 
 # GtkCellType's
 CELL_EMPTY   = 0
